[![Build Status](https://travis-ci.org/GeoffWilliams/profile_guard.svg?branch=master)](https://travis-ci.org/GeoffWilliams/profile_guard)
# profile_guard

#### Table of Contents

1. [Description](#description)
1. [Usage - Configuration options and additional functionality](#usage)
1. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
1. [Limitations - OS compatibility, etc.](#limitations)
1. [Development - Guide for contributing to the module](#development)

## Description

Profile Guard wraps [r_profile](https://forge.puppet.com/geoffwilliams/r_profile) profiles with the [trlinkin/noop](https://forge.puppet.com/trlinkin/noop) module in order to placing all resources contained into [noop mode](https://docs.puppet.com/puppet/latest/metaparameter.html#noop).

Each `profile_guard` profile used will be in noop mode until deactivated, which is normally done by setting the appropriate value in Hiera.


## Usage

See individual `profile_guard` classes for documentation.  Classes are typically used by including them, for example:

```puppet
include profile_guard::linux::ntp
```

Would activate `r_profile::linux::ntp` in noop mode.  When ready for `real` deployment, ensuring the hiera lookup for: `profile_guard::linux::ntp:noop_mode` returns `false` would apply the profile in enforcing mode to apply changes:

```json
profile_guard::linux::ntp:noop_mode: false
```

This pattern is used throughout the module

## Reference
Reference documentation is generated directly from source code using [puppet-strings](https://github.com/puppetlabs/puppet-strings).  You may regenerate the documentation by running:

```shell
bundle exec puppet strings
```

Or you may view the current [generated documentation](https://rawgit.com/GeoffWilliams/profile_guard/master/doc/index.html).

The documentation is no substitute for reading and understanding the module source code, and all users should ensure they are familiar and comfortable with the operations this module performs before using it.

## Limitations

* Not supported by Puppet, Inc.
* Depends entirely on the [trlinkin/noop](https://forge.puppet.com/trlinkin/noop) module for per-resource noop functionality

## Development

PRs accepted :)

## Testing
This module supports testing using [PDQTest](https://github.com/GeoffWilliams/pdqtest).

Test can be executed with:

```
bundle install
bundle exec pdqtest all
```
